@@ -14,7 +14,7 @@ from time import strptime
 from xbrl import TaxonomyNotFound, InstanceParseException
 from xbrl.cache import HttpCache
 from xbrl.taxonomy import Concept, TaxonomySchema, parse_taxonomy, parse_common_taxonomy, parse_taxonomy_url
-from xbrl.helper.uri_resolver import resolve_uri
+from xbrl.helper.uri_helper import resolve_uri
 from xbrl.helper.xml_parser import parse_file
 
 logger = logging.getLogger(__name__)
@@ -490,15 +490,21 @@ def _extract_ixbrl_value(fact_elem: ET.Element) -> float or str:
         elif value_format == 'numdotdecimal':
             raw_value = float(fact_elem.text.strip().replace(' ', '').replace(',', ''))
         elif value_format == 'datemonthdayen':
-            # Value is in the format Month(en) Day i.e: December 31
+            # Value is in the format Month(en) Day i.e: December 31 or Dec 31
             # convert it into the default format also used by standard xbrl (--MM-DD)
-            parsed_date = strptime(fact_elem.text, '%B %d')
+            if len(fact_elem.text.split(' ')[0]) == 3:
+                # The month is in the abbreviated form (i.e: Dec)
+                parsed_date = strptime(fact_elem.text, '%b %d')
+            else:
+                parsed_date = strptime(fact_elem.text, '%B %d')
             raw_value = '--{}-{}'.format(parsed_date.tm_mon, parsed_date.tm_mday)
         else:
             raw_value = str(fact_elem.text.strip())
 
     if isinstance(raw_value, float):
         raw_value = raw_value * pow(10, value_scale)
+        # Floating-point error mitigation
+        if abs(raw_value) > 1e6: raw_value = float(round(raw_value))
         if value_sign == '-':
             raw_value = -raw_value
 
