@@ -14,8 +14,8 @@ from functools import lru_cache
 
 from xbrl import XbrlParseException, TaxonomyNotFound
 from xbrl.cache import HttpCache
-from xbrl.helper.uri_resolver import resolve_uri
-from xbrl.linkbase import Linkbase, ExtendedLink, LinkbaseType, parse_linkbase, parse_linkbase_url
+from xbrl.helper.uri_helper import resolve_uri, compare_uri
+from xbrl.linkbase import Linkbase, ExtendedLink, LinkbaseType, parse_linkbase, parse_linkbase_url, Label
 
 logger = logging.getLogger(__name__)
 
@@ -37,6 +37,8 @@ ns_schema_map: dict = {
     "http://fasb.org/srt/2019-01-31": "http://xbrl.fasb.org/srt/2019/elts/srt-2019-01-31.xsd",
     "http://fasb.org/srt/2020-01-31": "http://xbrl.fasb.org/srt/2020/elts/srt-2020-01-31.xsd",
 
+    "http://xbrl.sec.gov/stpr/2018-01-31": "https://xbrl.sec.gov/stpr/2018/stpr-2018-01-31.xsd",
+
     "http://xbrl.sec.gov/country/2017-01-31": "https://xbrl.sec.gov/country/2017/country-2017-01-31.xsd",
     "http://xbrl.sec.gov/country/2020-01-31": "https://xbrl.sec.gov/country/2020/country-2020-01-31.xsd",
 
@@ -52,6 +54,7 @@ ns_schema_map: dict = {
     "http://xbrl.sec.gov/dei/2018-01-31": "https://xbrl.sec.gov/dei/2018/dei-2018-01-31.xsd",
     "http://xbrl.sec.gov/dei/2019-01-31": "https://xbrl.sec.gov/dei/2019/dei-2019-01-31.xsd",
     "http://xbrl.sec.gov/dei/2020-01-31": "https://xbrl.sec.gov/dei/2020/dei-2020-01-31.xsd",
+    "http://xbrl.sec.gov/dei/2021": "https://xbrl.sec.gov/dei/2021/dei-2021.xsd",
 
     "http://fasb.org/us-gaap/2011-01-31": "http://xbrl.fasb.org/us-gaap/2011/elts/us-gaap-2011-01-31.xsd",
     "http://fasb.org/us-gaap/2012-01-31": "http://xbrl.fasb.org/us-gaap/2012/elts/us-gaap-2012-01-31.xsd",
@@ -63,6 +66,7 @@ ns_schema_map: dict = {
     "http://fasb.org/us-gaap/2018-01-31": "http://xbrl.fasb.org/us-gaap/2018/elts/us-gaap-2018-01-31.xsd",
     "http://fasb.org/us-gaap/2019-01-31": "http://xbrl.fasb.org/us-gaap/2019/elts/us-gaap-2019-01-31.xsd",
     "http://fasb.org/us-gaap/2020-01-31": "http://xbrl.fasb.org/us-gaap/2020/elts/us-gaap-2020-01-31.xsd",
+    "http://fasb.org/us-gaap/2021-01-31": "http://xbrl.fasb.org/us-gaap/2021/elts/us-gaap-2021-01-31.xsd"
 }
 
 
@@ -90,6 +94,7 @@ class Concept:
         self.nillable: bool or None = None
         self.period_type: str or None = None
         self.balance: str or None = None
+        self.labels: [Label] = []
 
     def __str__(self) -> str:
         return self.name
@@ -161,19 +166,19 @@ class TaxonomySchema:
     def __str__(self) -> str:
         return self.namespace
 
-    def get_taxonomy(self, namespace: str):
+    def get_taxonomy(self, url: str):
         """
         Returns the taxonomy with the given namespace (if it is the current taxonomy, or if it is imported)
         If the taxonomy cannot be found, the function will return None
-        :param namespace:
+        :param url: can either be the namespace or the schema url
         :return either a TaxonomySchema obj or None
         :return:
         """
-        if self.namespace == namespace:
+        if compare_uri(self.namespace, url) or compare_uri(self.schema_url, url):
             return self
 
         for imported_tax in self.imports:
-            result = imported_tax.get_taxonomy(namespace)
+            result = imported_tax.get_taxonomy(url)
             if result is not None:
                 return result
         return None
@@ -327,4 +332,22 @@ def parse_taxonomy(schema_path: str, cache: HttpCache, schema_url: str or None =
                     elr.calculation_link = extended_cal_link
                     break
 
+    for label_linkbase in taxonomy.lab_linkbases:
+        for extended_link in label_linkbase.extended_links:
+            for root_locator in extended_link.root_locators:
+                # find the taxonomy the locator is referring to
+                schema_url, concept_id = root_locator.href.split('#')
+                c_taxonomy: TaxonomySchema = taxonomy.get_taxonomy(schema_url)
+                if c_taxonomy is None:
+                    if schema_url in ns_schema_map.values():
+                        c_taxonomy = parse_taxonomy_url(schema_url, cache)
+                        taxonomy.imports.append(c_taxonomy)
+                    else:
+                        continue
+                concept: Concept = c_taxonomy.concepts[concept_id]
+                concept.labels = []
+                for label_arc in root_locator.children:
+                    for label in label_arc.labels:
+                        concept.labels.append(label)
+
     return taxonomy
